# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from ConfigParser import (
    NoOptionError,
    SafeConfigParser
)
import os
import pwd
import sys

from offspring import offspring_root

config = None

def _read_config():
    global config
    config = SafeConfigParser()
    hostname = os.popen('hostname').read().strip()
    config.set('DEFAULT', 'base_dir', offspring_root)
    config.set('DEFAULT', 'hostname', hostname)
    config.set('DEFAULT', 'username', pwd.getpwuid(os.getuid())[0])

    if os.environ.has_key("OFFSPRING_CONFIGFILE"):
        CONFIGFILE_PATH = os.environ["OFFSPRING_CONFIGFILE"]
    else:
        CONFIGFILE_PATH = os.path.join(
            offspring_root, 'config', 'offspring.cfg')
    configFile = None
    try:
        configFile = open(CONFIGFILE_PATH)
        config.readfp(configFile)
    except Exception, e:
        sys.stderr.write("Fatal Error: Unable to parse configuration file '%s'. (%s)\n" \
            % (CONFIGFILE_PATH, e) )
        sys.exit(1)
    else:
        config.read([CONFIGFILE_PATH + '.' + hostname])
    finally:
        if configFile is not None:
            configFile.close()

_read_config()

def _make_getter(section):
    def getter(key, *default):
        try:
            return config.get(section, key, *default)
        except NoOptionError:
            if default:
                return default[0]
            else:
                raise
    return getter

def get(section, key):
    return config.get(section, key)

for section in config.sections():
    globals()[section] = _make_getter(section)
